@@ -44,10 +44,23 @@ AbstractOverlaySource::AbstractOverlaySource(AbstractOverlaySourcePrivate *dd, Q
 
 AbstractOverlaySource::~AbstractOverlaySource() = default;
 
+void AbstractOverlaySource::beginSwap()
+{
+}
+
+void AbstractOverlaySource::endSwap()
+{
+}
+
 void AbstractOverlaySource::hiddenElements([[maybe_unused]] std::vector<OSM::Element> &elems) const
 {
 }
 
+const std::vector<OSM::Node>* AbstractOverlaySource::transientNodes() const
+{
+    return nullptr;
+}
+
 
 ModelOverlaySource::ModelOverlaySource(QAbstractItemModel *model, QObject *parent)
     : AbstractOverlaySource(new ModelOverlaySourcePrivate, parent)
