@@ -8,6 +8,17 @@
 
 using namespace OSM;
 
+const char* OSM::typeName(Type type)
+{
+    switch(type) {
+        case OSM::Type::Null: Q_UNREACHABLE();
+        case OSM::Type::Node: return "node";
+        case OSM::Type::Way: return "way";
+        case OSM::Type::Relation: return "relation";
+    }
+    return nullptr;
+}
+
 DataSet::DataSet() = default;
 DataSet::DataSet(DataSet &&) noexcept = default;
 DataSet::~DataSet() = default;
@@ -36,10 +47,14 @@ Role DataSet::role(const char *roleName) const
 
 const Node* DataSet::node(Id id) const
 {
-    const auto it = std::lower_bound(nodes.begin(), nodes.end(), id);
-    if (it != nodes.end() && (*it).id == id) {
+    if (const auto it = std::lower_bound(nodes.begin(), nodes.end(), id); it != nodes.end() && (*it).id == id) {
         return &(*it);
     }
+    if (transientNodes) {
+        if (const auto it = std::lower_bound(transientNodes->begin(), transientNodes->end(), id); it != transientNodes->end() && (*it).id == id) {
+            return &(*it);
+        }
+    }
     return nullptr;
 }
 
